@@ -548,42 +548,42 @@ plotTracks(genetrack)
 
 
 ###################################################
-### code chunk number 68: features_3
+### code chunk number 68: features_3 (eval = FALSE)
 ###################################################
-trackList<-list()
-myStart<-min(features(myGene)$start)
-myEnd<-max(features(myGene)$end)
-myChr<-unique(features(myGene)$seqnames)
-genome<-'hg19'
-
-ideoTrack <- IdeogramTrack(genome = genome, chromosome = myChr)
-trackList<-c(trackList,ideoTrack)
-
-axtrack<-GenomeAxisTrack()
-trackList<-c(trackList,axtrack)
-
-genetrack<-makeGeneRegionTrack(myGene)
-genetrack
-
-trackList<-c(trackList,genetrack)
-
-biomTrack<-BiomartGeneRegionTrack(genome=genome,chromosome=as.character(myChr),
-		start=myStart,end=myEnd,name="ENSEMBL",showId=T)
-
-trackList<-c(trackList,biomTrack)
-
-conservation <- UcscTrack(genome = genome, chromosome = myChr,
-		track = "Conservation", table = "phyloP100wayAll",
-		from = myStart-2000, to = myEnd+2000, trackType = "DataTrack",
-		start = "start", end = "end", data = "score",
-		type = "hist", window = "auto", col.histogram = "darkblue",
-		fill.histogram = "darkblue", ylim = c(-3.7, 4),
-		name = "Conservation")
-
-trackList<-c(trackList,conservation)
-
-plotTracks(trackList,from=myStart-2000,to=myEnd+2000)
-
+## trackList<-list()
+## myStart<-min(features(myGene)$start)
+## myEnd<-max(features(myGene)$end)
+## myChr<-unique(features(myGene)$seqnames)
+## genome<-'hg19'
+## 
+## ideoTrack <- IdeogramTrack(genome = genome, chromosome = myChr)
+## trackList<-c(trackList,ideoTrack)
+## 
+## axtrack<-GenomeAxisTrack()
+## trackList<-c(trackList,axtrack)
+## 
+## genetrack<-makeGeneRegionTrack(myGene)
+## genetrack
+## 
+## trackList<-c(trackList,genetrack)
+## 
+## biomTrack<-BiomartGeneRegionTrack(genome=genome,chromosome=as.character(myChr),
+## 		start=myStart,end=myEnd,name="ENSEMBL",showId=T)
+## 
+## trackList<-c(trackList,biomTrack)
+## 
+## conservation <- UcscTrack(genome = genome, chromosome = myChr,
+## 		track = "Conservation", table = "phyloP100wayAll",
+## 		from = myStart-2000, to = myEnd+2000, trackType = "DataTrack",
+## 		start = "start", end = "end", data = "score",
+## 		type = "hist", window = "auto", col.histogram = "darkblue",
+## 		fill.histogram = "darkblue", ylim = c(-3.7, 4),
+## 		name = "Conservation")
+## 
+## trackList<-c(trackList,conservation)
+## 
+## plotTracks(trackList,from=myStart-2000,to=myEnd+2000)
+## 
 
 
 ###################################################
